include:
  - crypto
  - repositories
  - kubectl-config
  - kube-apiserver

{% from '_macros/certs.jinja' import alt_master_names, certs with context %}

{% set dex_alt_names = ["dex",
                        "dex.kube-system",
                        "dex.kube-system.svc",
                        "dex.kube-system.svc." + pillar['internal_infra_domain']] %}
{{ certs('dex',
         pillar['ssl']['dex_crt'],
         pillar['ssl']['dex_key'],
         cn = 'Dex',
         extra_alt_names = alt_master_names(dex_alt_names)) }}

/root/dex.yaml:
  file.managed:
    - source: salt://dex/dex.yaml
    - template: jinja
    - user: root
    - group: root
    - mode: 644
    - require:
      - caasp_retriable: /etc/pki/dex.crt

/root/roles.yaml:
  file.managed:
    - source: salt://dex/roles.yaml
    - template: jinja
    - user: root
    - group: root
    - mode: 644
    - require:
      - file: /root/dex.yaml

dex_secrets:
  cmd.run:
    - name: |
        until kubectl get secret dex-tls --namespace=kube-system ; do
            kubectl create secret generic dex-tls --namespace=kube-system --from-file=/etc/pki/dex.crt --from-file=/etc/pki/dex.key
            sleep 5
        done
    - env:
      - KUBECONFIG: {{ pillar['paths']['kubeconfig'] }}
    - require:
      - kube-apiserver
      - caasp_retriable: /etc/pki/dex.crt
      - {{ pillar['paths']['kubeconfig'] }}

dex_instance:
  cmd.run:
    - name: |
        kubectl apply -f /root/dex.yaml || kubectl apply -f /root/dex.yaml
    - env:
      - KUBECONFIG: {{ pillar['paths']['kubeconfig'] }}
    - require:
      - kube-apiserver
      - file: /root/dex.yaml
      - {{ pillar['paths']['kubeconfig'] }}

kubernetes_roles:
  cmd.run:
    - name: |
        kubectl apply -f /root/roles.yaml || kubectl apply -f /root/roles.yaml
    - env:
      - KUBECONFIG: {{ pillar['paths']['kubeconfig'] }}
    - require:
      - kube-apiserver
      - file: /root/roles.yaml
      - {{ pillar['paths']['kubeconfig'] }}
      - dex_instance

ensure_dex_running:
  # Wait until the Dex API is actually up and running
  http.wait_for_successful_query:
    {% set dex_api_server = "api." + pillar['internal_infra_domain']  -%}
    {% set dex_api_server_ext = pillar['api']['server']['external_fqdn'] -%}
    {% set dex_api_port = pillar['dex']['node_port'] -%}
    - name:       {{ 'https://' + dex_api_server + ':' + dex_api_port }}/.well-known/openid-configuration
    - wait_for:   300
    - ca_bundle:  {{ pillar['ssl']['ca_file'] }}
    - status:     200
    - header_dict:
        Host: {{ dex_api_server_ext + ':' + dex_api_port }}
    - watch:
      - /root/dex.yaml
      - /root/roles.yaml
