include:
  - crypto
  - repositories
  - kubernetes-common

kube-scheduler:
  pkg.installed:
    - pkgs:
      - kubernetes-master
    - require:
      - file: /etc/zypp/repos.d/containers.repo
  file.managed:
    - name: /etc/kubernetes/scheduler
    - source: salt://kube-scheduler/scheduler.jinja
    - template: jinja
  service.running:
    - enable: True
    - watch:
      - sls: kubernetes-common
      - file: kube-scheduler
      - kube-scheduler-config
    - require:
      - kube-scheduler-config

{{ pillar['ssl']['kube_scheduler_key'] }}:
  x509.private_key_managed:
    - bits: 4096
    - user: root
    - group: root
    - mode: 444
    - require:
      - sls:  crypto
      - file: /etc/pki

{{ pillar['ssl']['kube_scheduler_crt'] }}:
  caasp_retriable.retry:
    - target: x509.certificate_managed
    - ca_server: {{ salt['mine.get']('roles:ca', 'ca.crt', expr_form='grain').keys()[0] }}
    - signing_policy: minion
    - public_key: {{ pillar['ssl']['kube_scheduler_key'] }}
    - CN: 'system:kube-scheduler'
    - C: {{ pillar['certificate_information']['subject_properties']['C']|yaml_dquote }}
    - Email: {{ pillar['certificate_information']['subject_properties']['Email']|yaml_dquote }}
    - GN: {{ pillar['certificate_information']['subject_properties']['GN']|yaml_dquote }}
    - L: {{ pillar['certificate_information']['subject_properties']['L']|yaml_dquote }}
    # system:kube-scheduler is a kubernetes specific role identifying a scheduler in the system.
    - O: 'system:kube-scheduler'
    - OU: {{ pillar['certificate_information']['subject_properties']['OU']|yaml_dquote }}
    - SN: {{ pillar['certificate_information']['subject_properties']['SN']|yaml_dquote }}
    - ST: {{ pillar['certificate_information']['subject_properties']['ST']|yaml_dquote }}
    - basicConstraints: "critical CA:false"
    - keyUsage: nonRepudiation, digitalSignature, keyEncipherment
    - days_valid: {{ pillar['certificate_information']['days_valid']['certificate'] }}
    - days_remaining: {{ pillar['certificate_information']['days_remaining']['certificate'] }}
    - backup: True
    - user: root
    - group: root
    - mode: 644
    - retry:
        attempts: 5
    - require:
      - sls:  crypto
      - {{ pillar['ssl']['kube_scheduler_key'] }}

kube-scheduler-config:
  file.managed:
    - name: {{ pillar['paths']['kube_scheduler_config'] }}
    - source: salt://kubeconfig/kubeconfig.jinja
    - template: jinja
    - require:
      - pkg: kubernetes-common
      - caasp_retriable: {{ pillar['ssl']['kube_scheduler_crt'] }}
    - defaults:
        user: 'default-admin'
        client_certificate: {{ pillar['ssl']['kube_scheduler_crt'] }}
        client_key: {{ pillar['ssl']['kube_scheduler_key'] }}
